<template>
  <div>
    <div class="flex justify-between items-center mb-4">
      <h3 class="text-lg font-medium">AI Assistant Management</h3>
      <button @click="$emit('openAssistantModal')" class="px-4 py-2 bg-green-700 text-white rounded-md hover:bg-green-800 flex items-center">
        <span class="mr-1">+</span> Add AI Assistant
      </button>
    </div>
    
    <div class="bg-white rounded-lg shadow-sm border border-gray-100">
      <table class="min-w-full divide-y divide-gray-200">
        <thead class="bg-gray-50">
          <tr>
            <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase">Name</th>
            <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase">Description</th>
            <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase">Classification Purpose</th>
            <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase">Status</th>
            <th class="px-6 py-3 text-right text-xs font-medium text-gray-500 uppercase">Actions</th>
          </tr>
        </thead>
        <tbody class="bg-white divide-y divide-gray-200">
          <tr v-for="assistant in assistants" :key="assistant.id">
            <td class="px-6 py-4 whitespace-nowrap">{{ assistant.name }}</td>
            <td class="px-6 py-4">{{ assistant.description }}</td>
            <td class="px-6 py-4">{{ assistant.classification_purpose ? 'Yes' : 'No' }}</td>
            <td class="px-6 py-4">
              <span :class="assistant.enabled ? 'text-green-600' : 'text-red-600'">
                {{ assistant.enabled ? 'Enabled' : 'Disabled' }}
              </span>
            </td>
            <td class="px-6 py-4 text-right space-x-2">
              <button @click="$emit('openAssistantModal', assistant)" 
                      class="text-indigo-600 hover:text-indigo-900">
                Edit
              </button>
              <button @click="$emit('deleteAssistant', assistant.id)"
                      class="text-red-600 hover:text-red-900">
                Delete
              </button>
            </td>
          </tr>
          <tr v-if="assistants.length === 0">
            <td colspan="5" class="px-6 py-4 text-center text-gray-500">
              No AI assistants created yet
            </td>
          </tr>
        </tbody>
      </table>
    </div>
  </div>
</template>

<script>
export default {
  props: {
    assistants: {
      type: Array,
      required: true
    }
  },
  emits: ['openAssistantModal', 'deleteAssistant']
};
</script>
